@@ -547,7 +547,8 @@ class Install(MethodsInterface):
         new_nvidia_mask = self.clVars.Get('os_nvidia_mask')
         if new_nvidia_mask == current_nvidia_mask:
             return True
-        open(nvidia_mask_file, 'w').write(new_nvidia_mask)
+        with open(nvidia_mask_file, 'w') as f:
+            f.write(new_nvidia_mask)
         return True
 
     def changeScheduler(self, scheduler):
