@@ -416,7 +416,10 @@ class VariableClSplashImageHash(ReadonlyVariable):
     Контрольные суммы изображений для splashutils
     """
     hash_files = ("/etc/splash/calculate/images/verbose.md5",
-                  "/etc/splash/calculate/images/silent.md5")
+                  "/etc/splash/calculate/images/silent.md5",
+                  "/usr/share/plymouth/themes/calculate/boot.md5",
+                  "/usr/share/plymouth/themes/calculate/boot/md5sum",
+                  "/usr/share/plymouth/themes/calculate/calculate.plymouth")
 
     cfg_files = "/etc/splash/calculate/*.cfg"
 
